Computes the absolute difference between two field elements a and b using slack variables
to ensure that the result is correct without directly comparing the two values.
Enforces that the given value is in the range [0, 2^BITS - 1] (inclusive!). This is done by
introducing BITS new boolean variables and reconstructing the value from them.
(Naively!) enforces that the given value is in the range [0, bound] (inclusive!). This is done
by delegating to enforce_in_set with the set of all integers in that range.
Computes the maximum of two field elements a and b using slack variables to ensure that the
result is correct without directly comparing the two values.
Computes the minimum of two field elements a and b using slack variables to ensure that the
result is correct without directly comparing the two values.